<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>About</name>
    <message>
        <location filename="../qml/About.qml" line="27"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="46"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="49"/>
        <source>Thanks!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="52"/>
        <source>License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="86"/>
        <source>Version %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="90"/>
        <source>Using Qt %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="94"/>
        <source>Website</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="103"/>
        <source>Webcam capture application.</source>
        <translation type="unfinished">Webcam-Aufnahmeanwendung.</translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="106"/>
        <source>A simple webcam application for picture and video capture.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="122"/>
        <source>Thanks to all these cool people that helped contributing to Webcamoid all these years.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/About.qml" line="149"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddMedia</name>
    <message>
        <location filename="../qml/AddMedia.qml" line="28"/>
        <source>Add new media</source>
        <translation>Neue Medien hinzufügen</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="67"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="74"/>
        <source>Insert media description</source>
        <translation>Medienbeschreibung eingeben</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="81"/>
        <source>Media file</source>
        <translation>Mediendatei</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="89"/>
        <source>Select media file</source>
        <translation>Mediendatei auswählen</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="96"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="116"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="141"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../qml/AddMedia.qml" line="151"/>
        <source>Choose the file to add as media</source>
        <translation>Wählen Sie die Datei aus, die als Medium hinzugefügt werden soll</translation>
    </message>
</context>
<context>
    <name>AudioConfig</name>
    <message>
        <location filename="../qml/AudioConfig.qml" line="117"/>
        <source>Outputs</source>
        <translation>Ausgaben</translation>
    </message>
    <message>
        <location filename="../qml/AudioConfig.qml" line="121"/>
        <source>Select the output device for audio playing</source>
        <translation>Wählen Sie das Ausgabegerät für die Audiowiedergabe aus</translation>
    </message>
    <message>
        <location filename="../qml/AudioConfig.qml" line="134"/>
        <source>Inputs</source>
        <translation>Eingaben</translation>
    </message>
    <message>
        <location filename="../qml/AudioConfig.qml" line="137"/>
        <source>Select the device for audio capturing</source>
        <translation>Wählen Sie das Gerät für die Audioaufnahme aus</translation>
    </message>
    <message>
        <location filename="../qml/AudioConfig.qml" line="193"/>
        <location filename="../qml/AudioConfig.qml" line="295"/>
        <source>Silence</source>
        <translation>Stille</translation>
    </message>
</context>
<context>
    <name>AudioInfo</name>
    <message>
        <location filename="../qml/AudioInfo.qml" line="199"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../qml/AudioInfo.qml" line="214"/>
        <location filename="../qml/AudioInfo.qml" line="221"/>
        <source>Device description</source>
        <translation>Gerätebeschreibung</translation>
    </message>
    <message>
        <location filename="../qml/AudioInfo.qml" line="229"/>
        <location filename="../qml/AudioInfo.qml" line="244"/>
        <location filename="../qml/AudioInfo.qml" line="251"/>
        <source>Device id</source>
        <translation>Gerätekennung</translation>
    </message>
    <message>
        <location filename="../qml/AudioInfo.qml" line="266"/>
        <source>Sample Format</source>
        <translation>Abtastformat</translation>
    </message>
    <message>
        <location filename="../qml/AudioInfo.qml" line="292"/>
        <source>Channels</source>
        <translation>Kanäle</translation>
    </message>
    <message>
        <location filename="../qml/AudioInfo.qml" line="318"/>
        <source>Sample Rate</source>
        <translation>Abtastrate</translation>
    </message>
</context>
<context>
    <name>CodecConfigs</name>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/CodecConfigs.qml" line="27"/>
        <source>Configure %1</source>
        <translation>%1 konfigurieren</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/CodecConfigs.qml" line="112"/>
        <source>Search option</source>
        <translation>Suchoption</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/CodecConfigs.qml" line="126"/>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/CodecConfigs.qml" line="141"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/CodecConfigs.qml" line="151"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>ConfigBar</name>
    <message>
        <location filename="../qml/ConfigBar.qml" line="44"/>
        <source>Output</source>
        <translation>Ausgabe</translation>
    </message>
    <message>
        <location filename="../qml/ConfigBar.qml" line="48"/>
        <source>General Options</source>
        <translation>Allgemeine Optionen</translation>
    </message>
    <message>
        <location filename="../qml/ConfigBar.qml" line="52"/>
        <source>Plugins Configs</source>
        <translation>Plugin-Konfigurationen</translation>
    </message>
    <message>
        <location filename="../qml/ConfigBar.qml" line="56"/>
        <source>Updates</source>
        <translation>Aktualisierungen</translation>
    </message>
</context>
<context>
    <name>EffectBar</name>
    <message>
        <location filename="../qml/EffectBar.qml" line="122"/>
        <source>Search effect...</source>
        <translation>Effekt suchen...</translation>
    </message>
    <message>
        <location filename="../qml/EffectBar.qml" line="168"/>
        <source>None</source>
        <translation>Keine</translation>
    </message>
</context>
<context>
    <name>EffectConfig</name>
    <message>
        <location filename="../qml/EffectConfig.qml" line="96"/>
        <location filename="../qml/EffectConfig.qml" line="103"/>
        <source>Plugin id</source>
        <translation>Plug-In ID</translation>
    </message>
    <message>
        <location filename="../qml/EffectConfig.qml" line="83"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../qml/EffectConfig.qml" line="90"/>
        <source>Plugin description</source>
        <translation>Plug-In Beschreibung</translation>
    </message>
    <message>
        <location filename="../qml/EffectConfig.qml" line="119"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="../qml/EffectConfig.qml" line="119"/>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
</context>
<context>
    <name>GeneralConfig</name>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="46"/>
        <source>Play webcam on start</source>
        <translation>Webcam beim Start wiedergeben</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="52"/>
        <source>Enable advanced effects mode</source>
        <translation>Erweiterten Effektmodus aktivieren</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="58"/>
        <source>Frameworks &amp; libraries</source>
        <translation>Programmiergerüste &amp; Bibliotheken</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="68"/>
        <source>Video capture</source>
        <translation>Videoaufnahme</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="78"/>
        <source>Desktop capture</source>
        <translation>Desktop-Aufnahme</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="88"/>
        <source>Audio capture/play</source>
        <translation>Audioaufnahme/-wiedergabe</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="98"/>
        <source>Video convert</source>
        <translation>Videokonvertierung</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="108"/>
        <source>Audio convert</source>
        <translation>Audio-Konvertierung</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="149"/>
        <source>Virtual camera driver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="118"/>
        <source>Video playback</source>
        <translation>Videowiedergabe</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="128"/>
        <source>Video record</source>
        <translation>Videoaufnahme</translation>
    </message>
    <message>
        <location filename="../qml/GeneralConfig.qml" line="138"/>
        <source>Root method</source>
        <translation>Wurzelverfahren</translation>
    </message>
</context>
<context>
    <name>MediaBar</name>
    <message>
        <location filename="../qml/MediaBar.qml" line="62"/>
        <source>No webcams found</source>
        <translation>Keine Webcams gefunden</translation>
    </message>
</context>
<context>
    <name>MediaConfig</name>
    <message>
        <location filename="../qml/MediaConfig.qml" line="54"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="61"/>
        <source>Insert media description</source>
        <translation>Medienbeschreibung eingeben</translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="68"/>
        <source>Media UID</source>
        <translation>Medien-UID</translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="75"/>
        <source>Select media file</source>
        <translation>Mediendatei auswählen</translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="90"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="../qml/MediaConfig.qml" line="98"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
</context>
<context>
    <name>MediaTools</name>
    <message>
        <location filename="../../src/mediatools.cpp" line="223"/>
        <source>Daily Build</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OutputConfig</name>
    <message>
        <location filename="../qml/OutputConfig.qml" line="55"/>
        <source>Virtual camera</source>
        <translation>Virtuelle Kamera</translation>
    </message>
</context>
<context>
    <name>PhotoWidget</name>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="35"/>
        <source>%1 seconds</source>
        <translation>%1 Sekunden</translation>
    </message>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="56"/>
        <source>Now</source>
        <translation>Jetzt</translation>
    </message>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="80"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="80"/>
        <source>Shot!</source>
        <translation>Schuss!</translation>
    </message>
    <message>
        <location filename="../qml/PhotoWidget.qml" line="111"/>
        <source>Use flash</source>
        <translation>Blitz verwenden</translation>
    </message>
</context>
<context>
    <name>PluginConfig</name>
    <message>
        <location filename="../qml/PluginConfig.qml" line="110"/>
        <source>Use this page for configuring the plugins search paths.&lt;br /&gt;&lt;b&gt;Don&apos;t touch nothing unless you know what you are doing&lt;/b&gt;.</source>
        <translation>Verwenden Sie diese Seite zum Konfigurieren der Pluginsuchpfade.&lt;br /&gt;&lt;b&gt;Ändern Sie nichts, wenn Sie nicht wissen, was Sie tun&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="115"/>
        <source>Extra search paths</source>
        <translation>Zusätzliche Suchpfade</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="124"/>
        <source>Search plugins in subfolders.</source>
        <translation>Plugins in Unterordnern durchsuchen.</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="134"/>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="141"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="207"/>
        <source>Plugins list</source>
        <translation>Plugin-Liste</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="216"/>
        <source>Refresh</source>
        <translation>Aktualisieren</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="226"/>
        <source>Disable</source>
        <translation>Deaktivieren</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="226"/>
        <source>Enable</source>
        <translation>Aktivieren</translation>
    </message>
    <message>
        <location filename="../qml/PluginConfig.qml" line="308"/>
        <source>Add plugins search path</source>
        <translation>Plugins-Suchpfad hinzufügen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/clioptions.cpp" line="45"/>
        <source>Webcam capture application.</source>
        <translation>Webcam-Aufnahmeanwendung.</translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="48"/>
        <source>Load settings from PATH. If PATH is empty, load configs from application directory.</source>
        <translation>Einstellungen aus PATH laden. Konfigurationen aus Anwendungsverzeichnis laden, wenn PATH leer ist.</translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="50"/>
        <source>PATH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="54"/>
        <source>Semi-colon separated list of paths to search the Qml interface.</source>
        <translation>Semikolon getrennte Liste der Pfade zur Suche in der Qml-Oberfläche.</translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="56"/>
        <location filename="../../src/clioptions.cpp" line="68"/>
        <location filename="../../src/clioptions.cpp" line="74"/>
        <location filename="../../src/clioptions.cpp" line="80"/>
        <source>PATH1;PATH2;PATH3;...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="61"/>
        <source>Search in the specified plugins paths recursively.</source>
        <translation>Rekursiv in den angegebenen Plugin-Pfaden suchen.</translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="66"/>
        <source>Semi-colon separated list of paths to search for plugins.</source>
        <translation>Semikolon getrennte Liste der Pfade zur Suche nach Plugins.</translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="72"/>
        <source>Semi-colon separated list of paths to avoid loading.</source>
        <translation>Semikolon getrennte Liste der Pfade die am Laden gehindert werden.</translation>
    </message>
    <message>
        <location filename="../../src/clioptions.cpp" line="78"/>
        <source>Semi-colon separated list of paths to search for virtual camera driver</source>
        <translation>Semikolon getrennte Liste der Pfade zur Suche nach virtuellen Kameratreibern</translation>
    </message>
</context>
<context>
    <name>RecordBar</name>
    <message>
        <location filename="../qml/RecordBar.qml" line="101"/>
        <source>Search format...</source>
        <translation>Format suchen...</translation>
    </message>
</context>
<context>
    <name>RecordConfig</name>
    <message>
        <location filename="../qml/RecordConfig.qml" line="71"/>
        <source>Video %1.%2</source>
        <translation>Viedeo %1.%2</translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="88"/>
        <source>Stop recording video</source>
        <translation>Aufnahme des Videos stoppen</translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="91"/>
        <location filename="../qml/RecordConfig.qml" line="128"/>
        <source>Start recording video</source>
        <translation>Aufnahme des Videos starten</translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="99"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="106"/>
        <source>Insert format description</source>
        <translation>Formatbeschreibung eingeben</translation>
    </message>
    <message>
        <location filename="../qml/RecordConfig.qml" line="193"/>
        <source>Save video as...</source>
        <translation>Video speichern unter...</translation>
    </message>
</context>
<context>
    <name>Recording</name>
    <message>
        <location filename="../../src/recording.cpp" line="594"/>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <location filename="../../src/recording.cpp" line="595"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../../src/recording.cpp" line="596"/>
        <source>Subtitle</source>
        <translation>Untertitel</translation>
    </message>
    <message>
        <location filename="../../src/recording.cpp" line="661"/>
        <location filename="../../src/recording.cpp" line="827"/>
        <source>audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <location filename="../../src/recording.cpp" line="662"/>
        <location filename="../../src/recording.cpp" line="828"/>
        <source>video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../../src/recording.cpp" line="663"/>
        <location filename="../../src/recording.cpp" line="829"/>
        <source>subtitle</source>
        <translation>Untertitel</translation>
    </message>
</context>
<context>
    <name>StreamOptions</name>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="28"/>
        <source>Stream #%1 (%2)</source>
        <translation>Stream #%1 (%2)</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="29"/>
        <source>Stream #%1</source>
        <translation>Stream #%1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="64"/>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="85"/>
        <source>Bitrate</source>
        <translation>Bitrate</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="105"/>
        <source>GOP</source>
        <translation>GOP</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="110"/>
        <source>Separation between keyframes</source>
        <translation>Trennung zwischen Schlüsselbildern</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="126"/>
        <source>Advanced Codec Options</source>
        <translation>Erweiterte Codec-Optionen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="150"/>
        <source>Size of the audio (bits) / duration (seconds)</source>
        <translation>Größe des Audios (Bits) / Dauer (Sekunden)</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/StreamOptions.qml" line="171"/>
        <source>Size of the video (bits) / duration (seconds)</source>
        <translation>Größe des Videos (Bits) / Dauer (Sekunden)</translation>
    </message>
</context>
<context>
    <name>UpdatesConfig</name>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="68"/>
        <source>Notify about new versions</source>
        <translation>Über neue Versionen benachrichtigen</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="82"/>
        <source>Check new versions</source>
        <translation>Auf neue Versionen prüfen</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="90"/>
        <source>Daily</source>
        <translation>Täglich</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="94"/>
        <source>Every two days</source>
        <translation>Alle zwei Tage</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="98"/>
        <source>Weekly</source>
        <translation>Wöchentlich</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="102"/>
        <source>Every two weeks</source>
        <translation>Alle zwei Wochen</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="106"/>
        <source>Monthly</source>
        <translation>Monatlich</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="110"/>
        <source>Never</source>
        <translation>Nie</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="121"/>
        <source>Last updated</source>
        <translation>Letzte Aktualisierung</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="142"/>
        <source>Your version of %1 is outdated. Latest version is &lt;b&gt;%2&lt;/b&gt;.</source>
        <translation>Ihre Version von %1 ist veraltet. Neueste Version ist &lt;b&gt;%2&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="148"/>
        <source>Upgrade Now!</source>
        <translation>Jetzt aktualisieren!</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="163"/>
        <source>Thanks for using a &lt;b&gt;development version&lt;/b&gt;!&lt;br /&gt;It will be very helpful if you can report any bug and suggestions you have.</source>
        <translation>Danke für die Verwendung einer &lt;b&gt;Entwicklungsversion&lt;/b&gt;!&lt;br /&gt;Es wäre sehr hilfreich, wenn Sie irgendwelche Fehler und Vorschläge, die Sie haben, melden.</translation>
    </message>
    <message>
        <location filename="../qml/UpdatesConfig.qml" line="168"/>
        <source>Report a Bug</source>
        <translation>Fehler melden</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="172"/>
        <source>Recording</source>
        <translation>Aufnahme</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="111"/>
        <location filename="../qml/main.qml" line="618"/>
        <source>Play</source>
        <translation>Wiedergabe</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="652"/>
        <source>Take a photo</source>
        <translation>Foto aufnehmen</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="252"/>
        <source>Picture %1.%2</source>
        <translation>Bild %1.%2</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="71"/>
        <source>New version available!</source>
        <translation>Neue Version verfügbar!</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="72"/>
        <source>Download %1 %2 NOW!</source>
        <translation>%1 %2 JETZT herunterladen!</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="107"/>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="572"/>
        <source>Go back</source>
        <translation>Zurückgehen</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="626"/>
        <source>Configure sources</source>
        <translation>Quellen konfigurieren</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="639"/>
        <source>Configure audio</source>
        <translation>Audio konfigurieren</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="666"/>
        <source>Record video</source>
        <translation>Video aufnehmen</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="680"/>
        <source>Configure Effects</source>
        <translation>Effekte konfigurieren</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="693"/>
        <source>Preferences</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="706"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="261"/>
        <source>Save photo as...</source>
        <translation>Foto speichern unter...</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Aging/share/qml/main.qml" line="40"/>
        <source>Number of scratches</source>
        <translation>Anzahl der Kratzer</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Aging/share/qml/main.qml" line="62"/>
        <source>Add dust</source>
        <translation>Staub hinzufügen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Blur/share/qml/main.qml" line="40"/>
        <location filename="../../../libAvKys/Plugins/ColorFilter/share/qml/main.qml" line="77"/>
        <location filename="../../../libAvKys/Plugins/ColorReplace/share/qml/main.qml" line="93"/>
        <location filename="../../../libAvKys/Plugins/Denoise/share/qml/main.qml" line="43"/>
        <location filename="../../../libAvKys/Plugins/OilPaint/share/qml/main.qml" line="28"/>
        <source>Radius</source>
        <translation>Radius</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="85"/>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="256"/>
        <source>N° of colors</source>
        <translation>Anzahl der Farben</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="107"/>
        <source>Color difference</source>
        <translation>Farbunterschied</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="128"/>
        <source>Show edges</source>
        <translation>Kanten anzeigen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="141"/>
        <source>Threshold low</source>
        <translation>Schwellenwert niedrig</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="166"/>
        <source>Threshold high</source>
        <translation>Schwellenwert hoch</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="190"/>
        <source>Line color</source>
        <translation>Linienfarbe</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="205"/>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="215"/>
        <source>Scan block</source>
        <translation>Scan-Block</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cartoon/share/qml/main.qml" line="195"/>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="163"/>
        <source>Choose a color</source>
        <translation>Wählen Sie eine Farbe</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ChangeHSL/share/qml/main.qml" line="36"/>
        <location filename="../../../libAvKys/Plugins/ColorTransform/share/qml/main.qml" line="36"/>
        <location filename="../../../libAvKys/Plugins/MatrixTransform/share/qml/main.qml" line="35"/>
        <source>Transform matrix</source>
        <translation>Transformationsmatrix</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="63"/>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="72"/>
        <location filename="../../../libAvKys/Plugins/Hypnotic/share/qml/main.qml" line="52"/>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="63"/>
        <location filename="../../../libAvKys/Plugins/Ripple/share/qml/main.qml" line="41"/>
        <source>Mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="73"/>
        <source>Natural</source>
        <translation>Natürlich</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="77"/>
        <source>Fixed</source>
        <translation>Fest</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="86"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="76"/>
        <source>Symbols</source>
        <translation>Symbole</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="96"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="85"/>
        <source>Font</source>
        <translation>Schriftart</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="107"/>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="122"/>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="526"/>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="140"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="115"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="104"/>
        <source>Hinting</source>
        <translation>Hinting</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="125"/>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="156"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="114"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="145"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="129"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="118"/>
        <source>No hinting</source>
        <translation>Kein hinting</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="133"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="122"/>
        <source>Vertical hinting</source>
        <translation>Vertikales hinting</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="137"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="126"/>
        <source>Full hinting</source>
        <translation>Volles hinting</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="146"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="135"/>
        <source>Style</source>
        <translation>Stil</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="160"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="149"/>
        <source>Bitmap</source>
        <translation>Bitmap</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="164"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="153"/>
        <source>Device</source>
        <translation>Gerät</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="168"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="157"/>
        <source>Outline</source>
        <translation>Umriss</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="172"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="161"/>
        <source>Force outline</source>
        <translation>Umriss erzwingen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="176"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="165"/>
        <source>Match</source>
        <translation>Übereinstimmung</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="180"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="169"/>
        <source>Quality</source>
        <translation>Qualität</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="184"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="173"/>
        <source>Antialias</source>
        <translation>Kantenglättung</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="188"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="177"/>
        <source>No antialias</source>
        <translation>Keine Kantenglättung</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="192"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="181"/>
        <source>Compatible with OpenGL</source>
        <translation>Kompatibel mit OpenGL</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="196"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="185"/>
        <source>Force integer metrics</source>
        <translation>Ganzzahlige Metriken erzwingen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="200"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="189"/>
        <source>No subpixel antialias</source>
        <translation>Kein Subpixel-Antialias</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="204"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="193"/>
        <source>No font merging</source>
        <translation>Keine Schriftzusammenführung</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="213"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="212"/>
        <source>Foreground color</source>
        <translation>Vordergrundfarbe</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="224"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="222"/>
        <location filename="../../../libAvKys/Plugins/Wave/share/qml/main.qml" line="138"/>
        <source>Background color</source>
        <translation>Hintergrundfarbe</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="235"/>
        <source>Reversed</source>
        <translation>Umgekehrt</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="245"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="294"/>
        <source>Please choose a font</source>
        <translation>Bitte wählen Sie eine Schriftart aus</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="217"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="216"/>
        <source>Choose the foreground color</source>
        <translation>Wählen Sie die Vordergrundfarbe aus</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Charify/share/qml/main.qml" line="228"/>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="226"/>
        <location filename="../../../libAvKys/Plugins/Wave/share/qml/main.qml" line="142"/>
        <source>Choose the background color</source>
        <translation>Wählen Sie die Hintergrundfarbe aus</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cinema/share/qml/main.qml" line="61"/>
        <location filename="../../../libAvKys/Plugins/Dice/share/qml/main.qml" line="39"/>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cinema/share/qml/main.qml" line="84"/>
        <location filename="../../../libAvKys/Plugins/ColorFilter/share/qml/main.qml" line="60"/>
        <location filename="../../../libAvKys/Plugins/Life/share/qml/main.qml" line="64"/>
        <location filename="../../../libAvKys/Plugins/Vignette/share/qml/main.qml" line="69"/>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Cinema/share/qml/main.qml" line="88"/>
        <source>Choose the strips color</source>
        <translation>Wählen Sie die Streifenfarbe aus</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorFilter/share/qml/main.qml" line="100"/>
        <location filename="../../../libAvKys/Plugins/FalseColor/share/qml/main.qml" line="102"/>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="83"/>
        <source>Soft</source>
        <translation>Weich</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorFilter/share/qml/main.qml" line="64"/>
        <source>Select the color to filter</source>
        <translation>Wählen Sie die zu filternde Farbe aus</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorReplace/share/qml/main.qml" line="60"/>
        <source>Old color</source>
        <translation>Alte Farbe</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorReplace/share/qml/main.qml" line="76"/>
        <source>New color</source>
        <translation>Neue Farbe</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorReplace/share/qml/main.qml" line="64"/>
        <source>Select the color to replace</source>
        <translation>Wählen Sie die zu ersetzende Farbe aus</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorReplace/share/qml/main.qml" line="80"/>
        <source>Select the new color</source>
        <translation>Wählen Sie die neue Farbe aus</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="37"/>
        <location filename="../../../libAvKys/Plugins/FalseColor/share/qml/main.qml" line="75"/>
        <source>Color table</source>
        <translation>Farbtabelle</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="46"/>
        <source>Base</source>
        <translation>Basis</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="50"/>
        <source>Metal</source>
        <translation>Metall</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="54"/>
        <source>Heat</source>
        <translation>Hitze</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="58"/>
        <source>Old Photo</source>
        <translation>Altes Foto</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="62"/>
        <source>Red &amp; Green</source>
        <translation>Rot &amp; Grün</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="66"/>
        <source>Sepia</source>
        <translation>Sepia</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="70"/>
        <source>X-Pro</source>
        <translation>X-Pro</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="74"/>
        <source>X-Ray</source>
        <translation>Röntgen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="78"/>
        <source>Yellow &amp; Blue</source>
        <translation>Gelb &amp; Blau</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="82"/>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="484"/>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="101"/>
        <source>Custom</source>
        <translation>Benutzerdefiniert</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="103"/>
        <source>16x16 bitmap...</source>
        <translation>16x16 Bitmap...</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ColorTap/share/qml/main.qml" line="131"/>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="563"/>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="202"/>
        <source>Please choose an image file</source>
        <translation>Bitte wählen Sie eine Bilddatei aus</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Convolve/share/qml/main.qml" line="47"/>
        <source>Convolve matrix</source>
        <translation>Convolve-Matrix</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Convolve/share/qml/main.qml" line="153"/>
        <location filename="../../../libAvKys/Plugins/Denoise/share/qml/main.qml" line="64"/>
        <location filename="../../../libAvKys/Plugins/Emboss/share/qml/main.qml" line="29"/>
        <location filename="../../../libAvKys/Plugins/PrimariesColors/share/qml/main.qml" line="28"/>
        <source>Factor</source>
        <translation>Faktor</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Convolve/share/qml/main.qml" line="167"/>
        <location filename="../../../libAvKys/Plugins/Emboss/share/qml/main.qml" line="43"/>
        <source>Bias</source>
        <translation>Abweichung</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DelayGrab/share/qml/main.qml" line="42"/>
        <source>Grab mode</source>
        <translation>Grab-Modus</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DelayGrab/share/qml/main.qml" line="52"/>
        <source>Random square</source>
        <translation>Zufälliges Quadrat</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DelayGrab/share/qml/main.qml" line="56"/>
        <source>Vertical increase</source>
        <translation>Vertikale Erhöhung</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DelayGrab/share/qml/main.qml" line="60"/>
        <source>Horizontal increase</source>
        <translation>Horizontale Erhöhung</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DelayGrab/share/qml/main.qml" line="64"/>
        <source>Rings increase</source>
        <translation>Ringe erhöhen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DelayGrab/share/qml/main.qml" line="73"/>
        <location filename="../../../libAvKys/Plugins/Pixelate/share/qml/main.qml" line="41"/>
        <source>Block size</source>
        <translation>Blockgröße</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DelayGrab/share/qml/main.qml" line="86"/>
        <location filename="../../../libAvKys/Plugins/FrameOverlap/share/qml/main.qml" line="29"/>
        <location filename="../../../libAvKys/Plugins/Nervous/share/qml/main.qml" line="28"/>
        <location filename="../../../libAvKys/Plugins/Quark/share/qml/main.qml" line="28"/>
        <location filename="../../../libAvKys/Plugins/Warhol/share/qml/main.qml" line="28"/>
        <source>N° of frames</source>
        <translation>Anzahl der Bilder</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Denoise/share/qml/main.qml" line="78"/>
        <source>Mu</source>
        <translation>Mu</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Denoise/share/qml/main.qml" line="92"/>
        <source>Sigma</source>
        <translation>Sigma</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/DesktopCapture/share/qml/main.qml" line="48"/>
        <source>Frame rate</source>
        <translation>Bildwiederholrate</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Distort/share/qml/main.qml" line="29"/>
        <location filename="../../../libAvKys/Plugins/Ripple/share/qml/main.qml" line="64"/>
        <location filename="../../../libAvKys/Plugins/Wave/share/qml/main.qml" line="70"/>
        <source>Amplitude</source>
        <translation>Amplitude</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Distort/share/qml/main.qml" line="43"/>
        <location filename="../../../libAvKys/Plugins/Wave/share/qml/main.qml" line="93"/>
        <source>Frequency</source>
        <translation>Frequenz</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Distort/share/qml/main.qml" line="57"/>
        <source>Grid size</source>
        <translation>Rastergröße</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Dizzy/share/qml/main.qml" line="49"/>
        <source>Speed</source>
        <translation>Geschwindigkeit</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Dizzy/share/qml/main.qml" line="74"/>
        <source>Zoom rate</source>
        <translation>Zoomrate</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Dizzy/share/qml/main.qml" line="97"/>
        <source>Strength</source>
        <translation>Stärke</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Edge/share/qml/main.qml" line="44"/>
        <source>Canny mode</source>
        <translation>Canny-Modus</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Edge/share/qml/main.qml" line="57"/>
        <source>Lower Canny threshold</source>
        <translation>Untere Canny-Schwelle</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Edge/share/qml/main.qml" line="82"/>
        <source>Higger Canny threshold</source>
        <translation>Obere Canny-Schwelle</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Edge/share/qml/main.qml" line="107"/>
        <source>Equalize</source>
        <translation>Egalisieren</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Edge/share/qml/main.qml" line="119"/>
        <source>Invert</source>
        <translation>Invertieren</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="111"/>
        <source>Haar file</source>
        <translation>Haar-Datei</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="121"/>
        <source>Eye</source>
        <translation>Auge</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="125"/>
        <source>Eye glasses</source>
        <translation>Augengläser</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="129"/>
        <source>Frontal face alternative 1</source>
        <translation>Stirnfläche Alternative 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="133"/>
        <source>Frontal face alternative 2</source>
        <translation>Stirnseite Alternative 2</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="137"/>
        <source>Frontal face alternative 3</source>
        <translation>Stirnfläche Alternative 3</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="141"/>
        <source>Frontal face default</source>
        <translation>Standard Stirnfläche</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="145"/>
        <source>Full body</source>
        <translation>Ganzkörper</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="149"/>
        <source>Left Eye 1</source>
        <translation>Linkes Auge 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="153"/>
        <source>Lower body</source>
        <translation>Unterkörper</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="157"/>
        <source>Eye pair big</source>
        <translation>Augenpaar groß</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="161"/>
        <source>Eye pair small</source>
        <translation>Augenpaar klein</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="165"/>
        <source>Left ear</source>
        <translation>Linkes Ohr</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="169"/>
        <source>Left eye 2</source>
        <translation>Linkes Auge 2</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="173"/>
        <source>Mouth</source>
        <translation>Mund</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="177"/>
        <source>Nose</source>
        <translation>Nase</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="181"/>
        <source>Right ear</source>
        <translation>Rechtes Ohr</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="185"/>
        <source>Right Eye 1</source>
        <translation>Rechtes Auge 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="189"/>
        <source>Upper body 1</source>
        <translation>Oberkörper 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="193"/>
        <source>Profile face</source>
        <translation>Profilfläche</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="197"/>
        <source>Right eye 2</source>
        <translation>Rechtes Auge 2</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="201"/>
        <source>Smile</source>
        <translation>Lächeln</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="205"/>
        <source>Upper body</source>
        <translation>Oberkörper</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="229"/>
        <source>Marker type</source>
        <translation>Marker-Typ</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="239"/>
        <source>Rectangle</source>
        <translation>Rechteck</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="243"/>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="247"/>
        <source>Image</source>
        <translation>Bild</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="251"/>
        <source>Pixelate</source>
        <translation>Verpixeln</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="255"/>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="136"/>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="94"/>
        <source>Blur</source>
        <translation>Unschärfe</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="265"/>
        <source>Marker style</source>
        <translation>Marker-Stil</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="275"/>
        <source>Solid</source>
        <translation>Fest</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="279"/>
        <source>Dash</source>
        <translation>Strich</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="283"/>
        <source>Dot</source>
        <translation>Punkt</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="287"/>
        <source>Dash dot</source>
        <translation>Strich-Punkt</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="291"/>
        <source>Dash dot dot</source>
        <translation>Strich-Punkt-Punkt</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="301"/>
        <source>Marker color</source>
        <translation>Markerfarbe</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="313"/>
        <source>Marker width</source>
        <translation>Markerbreite</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="327"/>
        <source>Masks</source>
        <translation>Masken</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="336"/>
        <source>Angel</source>
        <translation>Engel</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="340"/>
        <source>Bear</source>
        <translation>Bär</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="344"/>
        <source>Beaver</source>
        <translation>Biber</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="348"/>
        <source>Cat</source>
        <translation>Katze</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="352"/>
        <source>Chicken</source>
        <translation>Huhn</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="356"/>
        <source>Cow</source>
        <translation>Kuh</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="360"/>
        <source>Devil</source>
        <translation>Teufel</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="364"/>
        <source>Dog</source>
        <translation>Hund</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="368"/>
        <source>Dalmatian dog</source>
        <translation>Dalmatinerhund</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="372"/>
        <source>Happy dog</source>
        <translation>Fröhlicher Hund</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="376"/>
        <source>Dragon</source>
        <translation>Drache</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="380"/>
        <source>Elephant 1</source>
        <translation>Elefant 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="384"/>
        <source>Elephant 2</source>
        <translation>Elefant 2</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="388"/>
        <source>Elk</source>
        <translation>Elch</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="392"/>
        <source>Frog</source>
        <translation>Frosch</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="396"/>
        <source>Ghost</source>
        <translation>Geist</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="400"/>
        <source>Giraffe</source>
        <translation>Giraffe</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="404"/>
        <source>Gnu</source>
        <translation>Gnu</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="408"/>
        <source>Goat</source>
        <translation>Ziege</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="412"/>
        <source>Hippo</source>
        <translation>Nilpferd</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="416"/>
        <source>Horse</source>
        <translation>Pferd</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="420"/>
        <source>Gray horse</source>
        <translation>Schimmel</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="424"/>
        <source>Koala</source>
        <translation>Koala</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="428"/>
        <source>Monkey</source>
        <translation>Affe</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="432"/>
        <source>Gray mouse</source>
        <translation>Graue Maus</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="436"/>
        <source>White mouse</source>
        <translation>Weiße Maus</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="440"/>
        <source>Panda</source>
        <translation>Panda</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="444"/>
        <source>Penguin</source>
        <translation>Pinguin</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="448"/>
        <source>Pumpkin 1</source>
        <translation>Kürbis 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="452"/>
        <source>Pumpkin 2</source>
        <translation>Kürbis 2</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="456"/>
        <source>Raccoon</source>
        <translation>Waschbär</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="460"/>
        <source>Rhino</source>
        <translation>Nashorn</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="464"/>
        <source>Sheep</source>
        <translation>Schaf</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="468"/>
        <source>Skull 1</source>
        <translation>Schädel 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="472"/>
        <source>Skull 2</source>
        <translation>Schädel 2</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="476"/>
        <source>Triceratops</source>
        <translation>Triceratops</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="480"/>
        <source>Zebra</source>
        <translation>Zebra</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="493"/>
        <source>Marker picture</source>
        <translation>Markerbild</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="507"/>
        <source>Replace face with this picture.</source>
        <translation>Gesicht mit diesem Bild ersetzen.</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="535"/>
        <source>Pixel grid size</source>
        <translation>Pixelrastergröße</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="549"/>
        <source>Blur radius</source>
        <translation>Unschärferadius</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FaceDetect/share/qml/main.qml" line="305"/>
        <source>Select marker color</source>
        <translation>Wählen Sie die Markerfarbe</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="87"/>
        <source>Hard</source>
        <translation>Hart</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="97"/>
        <source>Cooling</source>
        <translation>Kühlung</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="121"/>
        <source>Dissolve</source>
        <translation>Auflösen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="151"/>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="107"/>
        <source>Zoom</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="166"/>
        <location filename="../../../libAvKys/Plugins/Hypnotic/share/qml/main.qml" line="98"/>
        <location filename="../../../libAvKys/Plugins/Life/share/qml/main.qml" line="78"/>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="120"/>
        <location filename="../../../libAvKys/Plugins/Ripple/share/qml/main.qml" line="90"/>
        <source>Threshold</source>
        <translation>Schwellenwert</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="188"/>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="133"/>
        <location filename="../../../libAvKys/Plugins/Ripple/share/qml/main.qml" line="103"/>
        <source>Luma threshold</source>
        <translation>Luma-Schwellenwert</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="210"/>
        <source>Alpha diff</source>
        <translation>Alpha diff</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Fire/share/qml/main.qml" line="234"/>
        <source>Alpha variation</source>
        <translation>Alpha-Variation</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/FrameOverlap/share/qml/main.qml" line="43"/>
        <source>Stride</source>
        <translation>Schrittlänge</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="51"/>
        <source>Pattern</source>
        <translation>Muster</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="61"/>
        <source>90° Halftone 6x6</source>
        <translation>90° Halbton 6x6</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="65"/>
        <source>Cluster 3</source>
        <translation>Cluster 3</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="69"/>
        <source>Cluster 4</source>
        <translation>Cluster 4</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="73"/>
        <source>Cluster 8</source>
        <translation>Cluster 8</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="77"/>
        <source>Lines 4x4</source>
        <translation>Linien 4x4</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="81"/>
        <source>Magic 2x2</source>
        <translation>Magisch 2x2</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="85"/>
        <source>Magic 4x4</source>
        <translation>Magisch 4x4</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="89"/>
        <source>Ordered 4x4</source>
        <translation>Geordnet 4x4</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="93"/>
        <source>Ordered 6x6</source>
        <translation>Geordnet 6x6</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="97"/>
        <source>Ordered 8x8</source>
        <translation>Geordnet 8x8</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="120"/>
        <source>pattern bitmap...</source>
        <translation>Muster-Bitmap.....</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="149"/>
        <source>Pattern size</source>
        <translation>Mustergröße</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="162"/>
        <source>Lightness</source>
        <translation>Helligkeit</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="175"/>
        <source>Slope</source>
        <translation>Steigung</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Halftone/share/qml/main.qml" line="188"/>
        <source>Intercept</source>
        <translation>Abfangen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Hypnotic/share/qml/main.qml" line="63"/>
        <source>Spiral 1</source>
        <translation>Spirale 1</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Hypnotic/share/qml/main.qml" line="67"/>
        <source>Spiral 2</source>
        <translation>Spirale 2</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Hypnotic/share/qml/main.qml" line="71"/>
        <source>Parabola</source>
        <translation>Parabel</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Hypnotic/share/qml/main.qml" line="75"/>
        <source>Horizontal stripe</source>
        <translation>Horizontaler Streifen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Hypnotic/share/qml/main.qml" line="84"/>
        <source>Speed increment</source>
        <translation>Geschwindigkeitserhöhung</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Implode/share/qml/main.qml" line="28"/>
        <source>Amount</source>
        <translation>Menge</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Life/share/qml/main.qml" line="100"/>
        <source>Luma Threshold</source>
        <translation>Luma-Schwellenwert</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Life/share/qml/main.qml" line="68"/>
        <source>Choose the automata color</source>
        <translation>Wählen Sie die Farbe der Automata aus</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="63"/>
        <source>N° of drops</source>
        <translation>Anzahl der Drops</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="96"/>
        <source>Select</source>
        <translation>Auswählen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="202"/>
        <source>Cursor color</source>
        <translation>Cursor-Farbe</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="206"/>
        <source>Choose the cursor color</source>
        <translation>Wählen Sie die Farbe des Cursors</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="232"/>
        <source>Min. drop length</source>
        <translation>Min. Drop-Länge</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="245"/>
        <source>Max. drop length</source>
        <translation>Max. Drop-Länge</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="258"/>
        <source>Min. speed</source>
        <translation>Min. Geschwindigkeit</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="271"/>
        <source>Max. speed</source>
        <translation>Max. Geschwindigkeit</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Matrix/share/qml/main.qml" line="284"/>
        <source>Show cursor</source>
        <translation>Cursor anzeigen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/main.qml" line="166"/>
        <source>Output format</source>
        <translation>Ausgabeformat</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/main.qml" line="195"/>
        <source>File extensions</source>
        <translation>Dateiendungen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/main.qml" line="201"/>
        <source>This output format has not specific extensions</source>
        <translation>Dieses Ausgabeformat hat keine spezifischen Endungen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSink/share/qml/main.qml" line="207"/>
        <source>Advanced Format Options</source>
        <translation>Erweiterte Formatoptionen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSrc/share/qml/main.qml" line="119"/>
        <source>Video track</source>
        <translation>Videospur</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSrc/share/qml/main.qml" line="132"/>
        <source>Audio track</source>
        <translation>Audiospur</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/MultiSrc/share/qml/main.qml" line="145"/>
        <source>Subtitles track</source>
        <translation>Untertitelspur</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Nervous/share/qml/main.qml" line="41"/>
        <source>Simple</source>
        <translation>Einfach</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Photocopy/share/qml/main.qml" line="28"/>
        <source>Brightness</source>
        <translation>Helligkeit</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Photocopy/share/qml/main.qml" line="41"/>
        <source>Contrast</source>
        <translation>Kontrast</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="73"/>
        <source>Soft normal</source>
        <translation>Weich normal</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="77"/>
        <source>Hard normal</source>
        <translation>Hart normal</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="81"/>
        <source>Soft color</source>
        <translation>Soft-Farbe</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="85"/>
        <source>Hard color</source>
        <translation>Hart-Farbe</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="146"/>
        <source>Alpha differential</source>
        <translation>Alpha-Differenzial</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Radioactive/share/qml/main.qml" line="159"/>
        <source>Radiation color</source>
        <translation>Strahlungsfarbe</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Ripple/share/qml/main.qml" line="51"/>
        <source>Motion detect</source>
        <translation>Bewegungserkennung</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Ripple/share/qml/main.qml" line="55"/>
        <source>Rain</source>
        <translation>Regen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Ripple/share/qml/main.qml" line="77"/>
        <source>Decay</source>
        <translation>Verfall</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ScanLines/share/qml/main.qml" line="54"/>
        <source>Show lines</source>
        <translation>Linien anzeigen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ScanLines/share/qml/main.qml" line="67"/>
        <source>Hide lines</source>
        <translation>Linien ausblenden</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ScanLines/share/qml/main.qml" line="80"/>
        <source>Hide color</source>
        <translation>Ausblendungsfarbe</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/ScanLines/share/qml/main.qml" line="84"/>
        <source>Choose the hide color</source>
        <translation>Wählen Sie die Ausblendfarbe</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Scroll/share/qml/main.qml" line="44"/>
        <source>Vertical Sync</source>
        <translation>Vertikale Synchronisation</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Scroll/share/qml/main.qml" line="69"/>
        <source>Noise</source>
        <translation>Rauschen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Shagadelic/share/qml/main.qml" line="33"/>
        <source>Mask</source>
        <translation>Maske</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Swirl/share/qml/main.qml" line="38"/>
        <source>Degrees</source>
        <translation>Grade</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Temperature/share/qml/main.qml" line="38"/>
        <source>Temperature</source>
        <translation>Temperatur</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VideoCapture/share/qml/main.qml" line="215"/>
        <source>Video format</source>
        <translation>Videoformat</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VideoCapture/share/qml/main.qml" line="253"/>
        <source>Resolution</source>
        <translation>Auflösung</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VideoCapture/share/qml/main.qml" line="295"/>
        <source>FPS</source>
        <translation>BPS</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VideoCapture/share/qml/main.qml" line="344"/>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Vignette/share/qml/main.qml" line="83"/>
        <source>Aspect</source>
        <translation>Blickpunkt</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Vignette/share/qml/main.qml" line="106"/>
        <source>Scale</source>
        <translation>Skala</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Vignette/share/qml/main.qml" line="129"/>
        <source>Softness</source>
        <translation>Weichheit</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Vignette/share/qml/main.qml" line="73"/>
        <source>Choose the vignette color</source>
        <translation>Wählen Sie die Vignettenfarbe aus</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="61"/>
        <source>Devices</source>
        <translation>Geräte</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="78"/>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="89"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="102"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="113"/>
        <source>Remove All</source>
        <translation>Alles entfernen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="134"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="140"/>
        <source>Camera name (optional)</source>
        <translation>Kameraname (optional)</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="263"/>
        <source>Error creating camera</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="152"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="195"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/VirtualCamera/share/qml/main.qml" line="249"/>
        <source>This system is not supported yet</source>
        <translation>Dieses System wird noch nicht unterstützt</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Warp/share/qml/main.qml" line="28"/>
        <source>Ripples</source>
        <translation>Wellen</translation>
    </message>
    <message>
        <location filename="../../../libAvKys/Plugins/Wave/share/qml/main.qml" line="116"/>
        <source>Phase</source>
        <translation>Phase</translation>
    </message>
</context>
</TS>
